@@ -1,15 +1,10 @@
 
 #ifndef AUXILIARY_H
 #define AUXILIARY_H 1
- 
+
 #include "GSLvsR.h"
-#ifdef RF_FLOAT
-typedef float Real;
-#else
-typedef double Real;
-#endif 
-
 
+EXTERN void xyInchToPixels(double *xy, double *Pixels);
 EXTERN void RandomPermutation(double *x, int n, double *y 
 				  );
 EXTERN double quantile(double *X, int lb, double p);
@@ -18,7 +13,7 @@ EXTERN void pid(int *i);
 EXTERN void hostname(char **h, int *i);
 EXTERN void orderdouble(double *d,int *pos, int start, int end);
 EXTERN void quicksortdouble(double *d, int start, int end);
-EXTERN void vectordist(Real *v, int *dim, Real *dist, int *diag); 
+EXTERN void vectordist(double *v, int *dim, double *dist, int *diag); 
 
 
 EXTERN void I0ML0(double *x, int *n);
@@ -28,8 +23,8 @@ EXTERN void StruveH(double *x, double *nu);
 EXTERN void StruveL(double *x, double *nu, int * expScaled);
 EXTERN int InitRandom();
 
-EXTERN void ordering(Real *d, int len, int dim, int *pos);
-EXTERN void Ordering(Real *d, int *len, int *dim, int *pos);
+EXTERN void ordering(double *d, int len, int dim, int *pos);
+EXTERN void Ordering(double *d, int *len, int *dim, int *pos);
 
 #endif /* AUXILIARY_H */
 
